@@ -202,7 +202,8 @@ DRIVER nntpdriver = {
   nntp_expunge,			/* expunge deleted messages */
   nntp_copy,			/* copy messages to another mailbox */
   nntp_append,			/* append string message to mailbox */
-  NIL				/* garbage collect stream */
+  NIL,				/* garbage collect stream */
+  NIL				/* renew stream */
 };
 
 				/* prototype stream */
@@ -2057,6 +2058,7 @@ long nntp_send_auth_work (SENDSTREAM *stream,NETMBX *mb,char *pwd,long flags)
       sprintf (tmp,"Retrying using %s authentication after %.80s",
 	       at->name,lsterr);
       mm_log (tmp,NIL);
+      delete_password(mb, mb ? mb->user : NULL);
       fs_give ((void **) &lsterr);
     }
     trial = 0;			/* initial trial count */
@@ -2065,6 +2067,7 @@ long nntp_send_auth_work (SENDSTREAM *stream,NETMBX *mb,char *pwd,long flags)
       if (lsterr) {
 	sprintf (tmp,"Retrying %s authentication after %.80s",at->name,lsterr);
 	mm_log (tmp,WARN);
+	delete_password(mb, mb ? mb->user : NULL);
 	fs_give ((void **) &lsterr);
       }
       stream->saslcancel = NIL;
@@ -2095,6 +2098,8 @@ long nntp_send_auth_work (SENDSTREAM *stream,NETMBX *mb,char *pwd,long flags)
       sprintf (tmp,"Can not authenticate to NNTP server: %.80s",lsterr);
       mm_log (tmp,ERROR);
     }
+    if(!ret && stream->netstream)
+       delete_password(mb, mb ? mb->user : NULL);
     fs_give ((void **) &lsterr);
   }
   else if (mb->secflag)		/* no SASL, can't do /secure */
@@ -2123,6 +2128,8 @@ long nntp_send_auth_work (SENDSTREAM *stream,NETMBX *mb,char *pwd,long flags)
       stream->sensitive = T;	/* hide this command */
       if (nntp_send_work (stream,"AUTHINFO PASS",pwd2) == NNTPAUTHED)
 	ret = LONGT;		/* password OK */
+      else
+        delete_password(mb, mb ? mb->user : NULL);
       stream->sensitive = NIL;	/* unhide */
       if (ret) break;		/* OK if successful */
     default:			/* authentication failed */
